/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.util.List;
import nl.cloudfarming.client.isobus.model.IsobusTask;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 * 
 * @author Gerben Feenstra
 */
@Messages({
    "isobus.project.taskdata.node.name.task=Task ({0})"
})
public class AggregateTaskChildFactory extends ChildFactory<Node> {

    private static final String TASK_NODE_ICON = "";
    
    private final List<IsobusTask> tasks;

    public AggregateTaskChildFactory(List<IsobusTask> tasks) {
        this.tasks = tasks;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        for (IsobusTask task : tasks) {
            String displayName = NbBundle.getMessage(TaskDataChildFactory.class, "isobus.project.taskdata.node.name.task", task.getTaskId(), task.getTaskDesignator());
            toPopulate.add(new IsobusCommonNode(Children.create(new TaskChildFactory(task), true), task, TASK_NODE_ICON, displayName));
        }          
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
