/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.ProductAllocation;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * @author Gerben Feenstra
 */
@Messages("isobus.project.taskdata.node.name.allocationtime_product=AllocationTime ({0} - {1})")
public class ProductAllocationChildFactory extends ChildFactory<AllocationTime> {

    private static final String ALLOCATIONTIME_NODE_ICON = "nl/cloudfarming/client/isobus/type/isobus_taskdata_time.png";
    private final ProductAllocation productAllocation;

    public ProductAllocationChildFactory(ProductAllocation productAllocation) {
        this.productAllocation = productAllocation;
    }

    @Override
    protected boolean createKeys(List<AllocationTime> toPopulate) {
        toPopulate.add(productAllocation.getAllocationTimeStamp());
        return true;
    }

    @Override
    protected Node createNodeForKey(AllocationTime allocationTime) {
        String displayName = NbBundle.getMessage(ProductAllocationChildFactory.class, "isobus.project.taskdata.node.name.allocationtime_product", allocationTime.getStartTime(), allocationTime.getEndTime());
        return new IsobusCommonNode(Children.LEAF, allocationTime, ALLOCATIONTIME_NODE_ICON, displayName);

    }
}
